Django-Front
*********************

Django-front is a front-end editing application: placeholders can be defined in Django templates, which can then be edited on the front-end.

Currently supports: `Ace <http://ace.ajax.org/>`_, `EpicEditor <http://epiceditor.com/>`_, `Redactor <http://imperavi.com/redactor/>`_, `CKEditor <http://ckeditor.com/>`_ and `WYMeditor <http://www.wymeditor.org/>`_.

Please see the `online documentation <http://django-front.readthedocs.org/>`_ to install and get started.

.. image:: https://travis-ci.org/mbi/django-front.png?branch=master
  :target: http://travis-ci.org/mbi/django-front
.. image:: https://d2weczhvl823v0.cloudfront.net/mbi/django-front/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free


----

.. image:: http://django-front.readthedocs.org/en/latest/_images/front-edit-usage.gif




